Menu

Show posts

This section allows you to view all posts made by this member. Note that you can only see posts made in areas you currently have access to.

Show posts Menu

Messages - miyake

#276
General Development / Re: 600D Audio Controls?
July 28, 2012, 03:42:55 AM
patches with current my code

-audioki.c has no handling when vol change finished , added handler code in this patch
*also start recording.
-reset->override (fucntion name change)
-now reset audio had input select function


I think some configration task will need to add in override_audio_setting().  or audio_configure() directory.
If you add configration override code in audio_configure(), You need to change to call audio_configure() at startup/volchange/finish recording.



--- AUDIOREG-normal.TXT 2012-07-26 10:01:34.000000000 +0900
+++ AUDIOREG-volume0.TXT        2012-07-26 10:47:46.000000000 +0900
@@ -7,19 +7,19 @@
ML_CLK_EN 0f
ML_CLK_CTL 04
ML_SW_RST 00
-ML_REC_PLYBAK_RUN 11
+ML_REC_PLYBAK_RUN 00
ML_MIC_TIM 12
ML_PW_REF_PW_MNG 06
-ML_PW_IN_PW_MNG 0a
+ML_PW_IN_PW_MNG 00
ML_PW_DAC_PW_MNG 00
ML_PW_SPAMP_PW_MNG 00
ML_PW_LOUT_PW_MNG 00
ML_PW_ZCCMP_PW_MNG 02
ML_PW_MICBIAS_VOL 02
-ML_PW_MIC_IN_VOL 3f
-ML_PW_MIC_BOST_VOL 10
+ML_PW_MIC_IN_VOL 10
+ML_PW_MIC_BOST_VOL 00
ML_PW_SPK_AMP_VOL 1b
-ML_PW_AMP_VOL_FUNC 01
+ML_PW_AMP_VOL_FUNC 03
ML_PW_AMP_VOL_FADE 00
ML_SPK_AMP_OUT 00
ML_MIC_IF_CTL 00
@@ -27,10 +27,10 @@
ML_SAI_TRANS_CTL 0b
ML_SAI_RCV_CTL 0b
ML_SAI_MODE_SEL 00
-ML_FILTER_EN 0f
-ML_DVOL_CTL 2e
-ML_MIXER_VOL_CTL 10
-ML_RECORD_DIG_VOL ff
+ML_FILTER_EN 00
+ML_DVOL_CTL 2c
+ML_MIXER_VOL_CTL 00
+ML_RECORD_DIG_VOL 00
ML_PLBAK_DIG_VOL ff
ML_DIGI_BOOST_VOL 00
ML_EQ_GAIN_BRAND0 dd
@@ -89,8 +89,8 @@
ML_OUTPUT_LOUT 00
ML_OUTPUT_SPOUT 06
ML_OUTPUT_LOUTON 00
-AUDIO_IC_SIG1 0a
-AUDIO_IC_SIG2 0a
+AUDIO_IC_SIG1 00
+AUDIO_IC_SIG2 00
AUDIO_IC_IVL 00
AUDIO_IC_IVR 00
AUDIO_IC_PM1 06


vol max vs vol 0
--- AUDIOREG-volmax.TXT 2012-07-26 10:19:16.000000000 +0900
+++ AUDIOREG-volume0.TXT        2012-07-26 10:47:46.000000000 +0900
@@ -30,7 +30,7 @@
ML_FILTER_EN 00
ML_DVOL_CTL 2c
ML_MIXER_VOL_CTL 00
-ML_RECORD_DIG_VOL ff
+ML_RECORD_DIG_VOL 00
ML_PLBAK_DIG_VOL ff
ML_DIGI_BOOST_VOL 00
ML_EQ_GAIN_BRAND0 dd

#298
General Development / Re: 600D Audio Controls?
July 25, 2012, 03:43:47 AM
1% I'm restarting my camera every time.
The value is actual cannon firmware.

Another camera's register(AUDIO_SIG1) is added because , compile compatibility.
Dump definition is automatically generated by awk,sed. So never mind.
#299
General Development / Re: 600D Audio Controls?
July 25, 2012, 03:38:47 AM
standby vs standby(recording finish)
@@ -7,19 +7,19 @@
ML_CLK_EN 0f
ML_CLK_CTL 04
ML_SW_RST 00
-ML_REC_PLYBAK_RUN 11
+ML_REC_PLYBAK_RUN 00
ML_MIC_TIM 12
ML_PW_REF_PW_MNG 06
-ML_PW_IN_PW_MNG 0a
+ML_PW_IN_PW_MNG 00
ML_PW_DAC_PW_MNG 00
ML_PW_SPAMP_PW_MNG 00
ML_PW_LOUT_PW_MNG 00
ML_PW_ZCCMP_PW_MNG 02
ML_PW_MICBIAS_VOL 02
-ML_PW_MIC_IN_VOL 3f
-ML_PW_MIC_BOST_VOL 10
+ML_PW_MIC_IN_VOL 10
+ML_PW_MIC_BOST_VOL 00
ML_PW_SPK_AMP_VOL 1b
-ML_PW_AMP_VOL_FUNC 01
+ML_PW_AMP_VOL_FUNC 03
ML_PW_AMP_VOL_FADE 00
ML_SPK_AMP_OUT 00
ML_MIC_IF_CTL 00
@@ -27,8 +27,8 @@
ML_SAI_TRANS_CTL 0b
ML_SAI_RCV_CTL 0b
ML_SAI_MODE_SEL 00
-ML_FILTER_EN 0f
-ML_DVOL_CTL 2e
+ML_FILTER_EN 00
+ML_DVOL_CTL 2c
ML_MIXER_VOL_CTL 10
ML_RECORD_DIG_VOL ff
ML_PLBAK_DIG_VOL ff


recording vs standby(finish recording)
--- AUDIOREG-recording.TXT      2012-07-26 10:02:48.000000000 +0900
+++ AUDIOREG-finishrecording.txt        2012-07-26 10:36:54.000000000 +0900
@@ -7,19 +7,19 @@
ML_CLK_EN 0f
ML_CLK_CTL 04
ML_SW_RST 00
-ML_REC_PLYBAK_RUN 11
+ML_REC_PLYBAK_RUN 00
ML_MIC_TIM 12
ML_PW_REF_PW_MNG 06
-ML_PW_IN_PW_MNG 0a
+ML_PW_IN_PW_MNG 00
ML_PW_DAC_PW_MNG 00
ML_PW_SPAMP_PW_MNG 00
ML_PW_LOUT_PW_MNG 00
ML_PW_ZCCMP_PW_MNG 02
ML_PW_MICBIAS_VOL 02
-ML_PW_MIC_IN_VOL 37
-ML_PW_MIC_BOST_VOL 10
+ML_PW_MIC_IN_VOL 10
+ML_PW_MIC_BOST_VOL 00
ML_PW_SPK_AMP_VOL 1b
-ML_PW_AMP_VOL_FUNC 01
+ML_PW_AMP_VOL_FUNC 03
ML_PW_AMP_VOL_FADE 00
ML_SPK_AMP_OUT 00
ML_MIC_IF_CTL 00
@@ -27,7 +27,7 @@
ML_SAI_TRANS_CTL 0b
ML_SAI_RCV_CTL 0b
ML_SAI_MODE_SEL 00
-ML_FILTER_EN 0f
+ML_FILTER_EN 00
ML_DVOL_CTL 2c
ML_MIXER_VOL_CTL 10
ML_RECORD_DIG_VOL ff




So I thinik , these difference make a stopping audio meter.
#300
General Development / Re: 600D Audio Controls?
July 25, 2012, 03:08:31 AM
normal(not recording,standby)
ML_SMPLING_RATE 08
ML_PLLNL 96
ML_PLLNH 00
ML_PLLML 00
ML_PLLMH 03
ML_PLLDIV 05
ML_CLK_EN 0f
ML_CLK_CTL 04
ML_SW_RST 00
ML_REC_PLYBAK_RUN 11
ML_MIC_TIM 12
ML_PW_REF_PW_MNG 06
ML_PW_IN_PW_MNG 0a
ML_PW_DAC_PW_MNG 00
ML_PW_SPAMP_PW_MNG 00
ML_PW_LOUT_PW_MNG 00
ML_PW_ZCCMP_PW_MNG 02
ML_PW_MICBIAS_VOL 02
ML_PW_MIC_IN_VOL 3f
ML_PW_MIC_BOST_VOL 10
ML_PW_SPK_AMP_VOL 1b
ML_PW_AMP_VOL_FUNC 01
ML_PW_AMP_VOL_FADE 00
ML_SPK_AMP_OUT 00
ML_MIC_IF_CTL 00
ML_MIC_SELECT 01
ML_SAI_TRANS_CTL 0b
ML_SAI_RCV_CTL 0b
ML_SAI_MODE_SEL 00
ML_FILTER_EN 0f
ML_DVOL_CTL 2e
ML_MIXER_VOL_CTL 10
ML_RECORD_DIG_VOL ff
ML_PLBAK_DIG_VOL ff
ML_DIGI_BOOST_VOL 00
ML_EQ_GAIN_BRAND0 dd
ML_EQ_GAIN_BRAND1 dd
ML_EQ_GAIN_BRAND2 e7
ML_EQ_GAIN_BRAND3 e7
ML_EQ_GAIN_BRAND4 e7
ML_HPF2_CUTOFF 04
ML_EQBRAND0_F0L 0d
ML_EQBRAND0_F0H db
ML_EQBRAND0_F1L 0c
ML_EQBRAND0_F1H 1b
ML_EQBRAND1_F0L 6d
ML_EQBRAND1_F0H 08
ML_EQBRAND1_F1L 41
ML_EQBRAND1_F1H ed
ML_EQBRAND2_F0L 00
ML_EQBRAND2_F0H 00
ML_EQBRAND2_F1L 00
ML_EQBRAND2_F1H 00
ML_EQBRAND3_F0L 00
ML_EQBRAND3_F0H 00
ML_EQBRAND3_F1L 00
ML_EQBRAND3_F1H 00
ML_EQBRAND4_F0L 00
ML_EQBRAND4_F0H 00
ML_EQBRAND4_F1L 00
ML_EQBRAND4_F1H 00
ML_ALC_MODE 01
ML_ALC_ATTACK_TIM 08
ML_ALC_DECAY_TIM 08
ML_ALC_HOLD_TIM 00
ML_ALC_TARGET_LEV 0b
ML_ALC_MAXMIN_GAIN 70
ML_NOIS_GATE_THRSH 00
ML_ALC_ZERO_TIMOUT 01
ML_PL_ATTACKTIME 04
ML_PL_DECAYTIME 05
ML_PL_TARGETTIME 0d
ML_PL_MAXMIN_GAIN 70
ML_PLYBAK_BOST_VOL 10
ML_PL_0CROSS_TIMOUT 00
ML_NODOC_E5 06
ML_INPUT_ADC 08
ML_INPUT_ANALOG_SINGLE 08
ML_INPUT_ANALOG_DIFF 08
ML_INPUT_PGA 08
ML_SUP_DAC_MCLKEN 08
ML_SUP_ADC_MCLKEN 08
ML_SUP_DAC_PLLEN 08
ML_SUP_ADC_PLLEN 08
ML_SUP_DAC_PLLOE 08
ML_SUP_ADC_PLLOE 96
ML_OUTMIX_DACSW 00
ML_OUTMIX_LOOPSW 03
ML_OUTPUT_LOUT 00
ML_OUTPUT_SPOUT 06
ML_OUTPUT_LOUTON 00
AUDIO_IC_SIG1 0a
AUDIO_IC_SIG2 0a
AUDIO_IC_IVL 00
AUDIO_IC_IVR 00
AUDIO_IC_PM1 06
AUDIO_IC_PM3 02
AUDIO_IC_MODE3 02
AUDIO_IC_MODE4 02
AUDIO_IC_FIL1 02
AUDIO_IC_ALCVOL 00
AUDIO_IC_ALC1 00


AGC off , windocut off
diff of normal and recording
]
--- AUDIOREG-normal.TXT 2012-07-26 10:01:34.000000000 +0900
+++ AUDIOREG-recording.TXT      2012-07-26 10:02:48.000000000 +0900
@@ -16,7 +16,7 @@
ML_PW_LOUT_PW_MNG 00
ML_PW_ZCCMP_PW_MNG 02
ML_PW_MICBIAS_VOL 02
-ML_PW_MIC_IN_VOL 3f
+ML_PW_MIC_IN_VOL 37
ML_PW_MIC_BOST_VOL 10
ML_PW_SPK_AMP_VOL 1b
ML_PW_AMP_VOL_FUNC 01
@@ -28,7 +28,7 @@
ML_SAI_RCV_CTL 0b
ML_SAI_MODE_SEL 00
ML_FILTER_EN 0f
-ML_DVOL_CTL 2e
+ML_DVOL_CTL 2c
ML_MIXER_VOL_CTL 10
ML_RECORD_DIG_VOL ff
ML_PLBAK_DIG_VOL ff


AGCoff and AGCon
--- AUDIOREG-normal.TXT 2012-07-26 10:01:34.000000000 +0900
+++ AUDIOREG-AGCon.TXT  2012-07-26 10:05:46.000000000 +0900
@@ -7,19 +7,19 @@
ML_CLK_EN 0f
ML_CLK_CTL 04
ML_SW_RST 00
-ML_REC_PLYBAK_RUN 11
+ML_REC_PLYBAK_RUN 00
ML_MIC_TIM 12
ML_PW_REF_PW_MNG 06
-ML_PW_IN_PW_MNG 0a
+ML_PW_IN_PW_MNG 00
ML_PW_DAC_PW_MNG 00
ML_PW_SPAMP_PW_MNG 00
ML_PW_LOUT_PW_MNG 00
ML_PW_ZCCMP_PW_MNG 02
ML_PW_MICBIAS_VOL 02
-ML_PW_MIC_IN_VOL 3f
-ML_PW_MIC_BOST_VOL 10
+ML_PW_MIC_IN_VOL 10
+ML_PW_MIC_BOST_VOL 00
ML_PW_SPK_AMP_VOL 1b
-ML_PW_AMP_VOL_FUNC 01
+ML_PW_AMP_VOL_FUNC 03
ML_PW_AMP_VOL_FADE 00
ML_SPK_AMP_OUT 00
ML_MIC_IF_CTL 00
@@ -27,9 +27,9 @@
ML_SAI_TRANS_CTL 0b
ML_SAI_RCV_CTL 0b
ML_SAI_MODE_SEL 00
-ML_FILTER_EN 0f
+ML_FILTER_EN 00
ML_DVOL_CTL 2e
-ML_MIXER_VOL_CTL 10
+ML_MIXER_VOL_CTL 00
ML_RECORD_DIG_VOL ff
ML_PLBAK_DIG_VOL ff
ML_DIGI_BOOST_VOL 00



volume 70% vs 100%

--- AUDIOREG-normal.TXT 2012-07-26 10:01:34.000000000 +0900
+++ AUDIOREG-volmax.TXT 2012-07-26 10:19:16.000000000 +0900
@@ -7,19 +7,19 @@
ML_CLK_EN 0f
ML_CLK_CTL 04
ML_SW_RST 00
-ML_REC_PLYBAK_RUN 11
+ML_REC_PLYBAK_RUN 00
ML_MIC_TIM 12
ML_PW_REF_PW_MNG 06
-ML_PW_IN_PW_MNG 0a
+ML_PW_IN_PW_MNG 00
ML_PW_DAC_PW_MNG 00
ML_PW_SPAMP_PW_MNG 00
ML_PW_LOUT_PW_MNG 00
ML_PW_ZCCMP_PW_MNG 02
ML_PW_MICBIAS_VOL 02
-ML_PW_MIC_IN_VOL 3f
-ML_PW_MIC_BOST_VOL 10
+ML_PW_MIC_IN_VOL 10
+ML_PW_MIC_BOST_VOL 00
ML_PW_SPK_AMP_VOL 1b
-ML_PW_AMP_VOL_FUNC 01
+ML_PW_AMP_VOL_FUNC 03
ML_PW_AMP_VOL_FADE 00
ML_SPK_AMP_OUT 00
ML_MIC_IF_CTL 00
@@ -27,9 +27,9 @@
ML_SAI_TRANS_CTL 0b
ML_SAI_RCV_CTL 0b
ML_SAI_MODE_SEL 00
-ML_FILTER_EN 0f
-ML_DVOL_CTL 2e
-ML_MIXER_VOL_CTL 10
+ML_FILTER_EN 00
+ML_DVOL_CTL 2c
+ML_MIXER_VOL_CTL 00
ML_RECORD_DIG_VOL ff
ML_PLBAK_DIG_VOL ff
ML_DIGI_BOOST_VOL 00
diff -r 4fdf51b053f0 src/audioki.c
--- a/src/audioki.c     Sat Jul 28 02:37:01 2012 +0200
+++ b/src/audioki.c     Sat Jul 28 10:59:12 2012 +0900
@@ -1169,45 +1169,34 @@
}

void
-reset_audio_setting(int phase){
+override_audio_setting(int phase){

        //These audio_ic_write are setting back to startup time.
        //Because, the canon firmware will switching off the audio switchs I guess,it's for power save
     switch(phase){
-               case 0:
-                       //for startup
-                       audio_ic_write(ML_PW_ZCCMP_PW_MNG | 0x02);
-                       audio_ic_write(ML_MIC_TIM | 0x12);
-                       audio_ic_write(ML_EQ_GAIN_BRAND0 | 0xdd);
-                       audio_ic_write(ML_EQ_GAIN_BRAND1 | 0xdd);
-                       audio_ic_write(ML_HPF2_CUTOFF | 0x04);
-                       audio_ic_write(ML_EQBRAND0_F0L | 0x0d);
-                       audio_ic_write(ML_EQBRAND0_F0H | 0xdb);
-                       audio_ic_write(ML_EQBRAND0_F1L | 0x0c);
-                       audio_ic_write(ML_EQBRAND0_F1H | 0x1b);
-                       audio_ic_write(ML_EQBRAND1_F0L | 0x6d);
-                       audio_ic_write(ML_EQBRAND1_F0H | 0x08);
-                       audio_ic_write(ML_EQBRAND1_F1L | 0x41);
-                       audio_ic_write(ML_EQBRAND1_F1H | 0xed);
-                       audio_ic_write(ML_NODOC_E5 | 0x06);
-
-               case 1:
-
-                       audio_ic_write(ML_REC_PLYBAK_RUN | 0x11); //
-                       audio_ic_write(ML_PW_IN_PW_MNG | 0x0a);   //DAC(0010) and PGA(1000) power on
-
-                       audio_ic_write(ML_DVOL_CTL | 0x2E);        //All(Play,Capture,DigitalVolFade,DigitalVol) switched on
-                       audio_ic_write(ML_PW_MIC_IN_VOL | 0x3f);
-                       audio_ic_write(ML_PW_MIC_BOST_VOL | 0x10);
-                       audio_ic_write(ML_PW_AMP_VOL_FUNC | 0x01);
-                       audio_ic_write(ML_FILTER_EN | 0x0f);       //All filter on
-                       audio_ic_write(ML_MIXER_VOL_CTL | 0x10);
-                       break;
+    case 0:   //Phase 0 for camera powerON->standby
+        audio_ic_write(ML_NODOC_E5 | 0x02); //Duplicate L to R
+
+    case 1: //Phase 1 for finish recording->standy & change vol setting->standby
+        audio_ic_write(ML_REC_PLYBAK_RUN | 0x11); //
+        audio_ic_write(ML_PW_IN_PW_MNG | 0x0a);   //DAC(0010) and PGA(1000) power on
+        audio_ic_write(ML_DVOL_CTL | 0x2E);        //All(Play,Capture,DigitalVolFade,DigitalVol) switched on
+        audio_ic_write(ML_PW_MIC_IN_VOL | 0x3f);
+        audio_ic_write(ML_FILTER_EN | 0x0f);       //All filter on
+
+        int inputsource = get_input_source();
+        if(inputsource == 0){ //int/int
+            audio_ic_write(ML_MIC_SELECT | 0x01);
+            audio_ic_write(ML_NODOC_E5 | 0x02); //Duplicate L to R
+        }else if(inputsource == 2){
+            audio_ic_write(ML_MIC_SELECT | 0x02);
+            audio_ic_write(ML_NODOC_E5 | 0x00);
+        }
     }
}


-struct msg_queue * reset_audio_q = NULL;
+struct msg_queue * override_audio_q = NULL;
short gIs_UnInitialized = 0;
//#endif

@@ -1229,15 +1218,14 @@
         #else*/
//miyake code #ifdef CONFIG_600D
        int msg;
-       int err = msg_queue_receive(reset_audio_q, (struct event**)&msg, 500);
+       int err = msg_queue_receive(override_audio_q, (struct event**)&msg, 500);
        if (!err){
-               reset_audio_setting(1);
+               override_audio_setting(1);
        }

        if(gIs_UnInitialized < 3){
                msleep(500);
-               reset_audio_setting(0);
-               //              disp_logoutput("reset audio");
+               override_audio_setting(0);
                gIs_UnInitialized++;
        }

@@ -2283,11 +2271,14 @@
         case 0:
             // Movie recording stopped;  (fallthrough)
#ifdef CONFIG_600D
-                       reset_audio_setting(1);
+                       override_audio_setting(1);
#endif
                case 2:
             // Movie recording started
             give_semaphore( gain.sem );
+#ifdef CONFIG_600D
+            override_audio_setting(1);
+#endif
             break;
         case 1:
             // Movie recording about to start?
@@ -2815,10 +2806,14 @@

PROP_HANDLER( PROP_AUDIO_VOL_CHANGE_600D )
{
-    /* Cannot overwrite audio config here!
-        Cannon firmware is overwrite after finishing here.
-
+    /* Cannot override audio config here!
+        Cannon firmware is override after finishing here.
         */
+    if(!override_audio_q)
+    override_audio_q = (struct msg_queue *) msg_queue_create("override_audio_q", 1);
+
+    msg_queue_post(override_audio_q, 1);
+
}

PROP_HANDLER( PROP_PLAYMODE_LAUNCH_600D )
@@ -2831,4 +2826,4 @@



-#endif
\ No newline at end of file
+#endif
#277
General Development / Re: 600D Audio Controls?
July 27, 2012, 05:56:02 AM
go go scrax!
My English might be poor. So all of my understanding is in my code.

Also just write this
http://magiclantern.wikia.com/wiki/File:Audioicworking.png
#278
General Development / Re: 600D Audio Controls?
July 26, 2012, 06:27:40 PM
1 % you are correct!
0xe506 is work for me.
I was  miss understanding.


#279
General Development / Re: 600D Audio Controls?
July 26, 2012, 09:07:43 AM
I didn't touch 0xE1, but now my 600D is working stereo audio meter.
working is not clone.
#280
General Development / Re: 600D Audio Controls?
July 26, 2012, 07:40:39 AM
someone help

Current 600D audio wikia is little difficult to read
http://magiclantern.wikia.com/wiki/600D/Audio

So please help to solve like this.
600D (Oki ML26121A)                                550D (AK4646)
DisableAudioIC
2100 (ML_PW_REF_PW_MNG )                            2100
0d00 (ML_CLK_EN)                                              0d00


How to solve it.
ex:First line

2100                                                               2100


Then find 0x2100 in:
https://bitbucket.org/miyake_t/magic-lantern-miyake/src/464c27ee1aba/src/audio.h
line 161-261


#define ML_PW_REF_PW_MNG                0x2100 /* MICBIAS */ /* Reference Power Management */


Then edit wikia such as first example.

Is this a enough for explainning?
#281
General Development / Re: 600D Audio Controls?
July 26, 2012, 07:27:16 AM
Quote from: 1% on July 25, 2012, 05:53:53 PM
I can confirm 0a is not default value for input power managment. Camera starts with no meter... I PTP

c 0xFF06A144 0x230a
and

c 0xFF06A144 0x1311 (or 13, hehehe)

Meter works

just setting rec mode does not. have to power the amp first (or after)


*** Maybe we just cut the function to those 2 settings, why set all the other stuff it just messes with things.

Also clone to stereo if you want afterwards for internal mic:

e1=02 - recording 1 channel
e1 = 01 recording 2 channels


I just facing same issue.
When I add audio menus and some related function enabled, Audio metar woking only L.
I'm not set any audio_ic_write at just launched.
Therefore,
1: Canons initialization is depend on some another configs.
2: Added overwrite IC setting when finish cannon initialization.(little tricky )

#282
General Development / Re: 600D Audio Controls?
July 25, 2012, 07:01:53 PM
@1%

done, menu inserted now. But menu handling functions are not working now.

and Good night!
#283
General Development / Re: 600D Audio Controls?
July 25, 2012, 06:11:59 PM
Quote from: 1% on July 25, 2012, 06:07:19 PM
Yes, far mic to record audio.. close mic to start recording with the clapper, etc. That way we actually have a use for the internal.

:( post rate limits

Ah, I see. but now, AUDIO_SIG1,2 is only multiplexed output, It's my understanding.
Do you know how to get audio signal level separately with int/ext?
#284
General Development / Re: 600D Audio Controls?
July 25, 2012, 06:09:17 PM
Quote from: 1% on July 25, 2012, 05:53:53 PM
I can confirm 0a is not default value for input power managment. Camera starts with no meter... I PTP
c 0xFF06A144 0x230a
and
c 0xFF06A144 0x1311 (or 13, hehehe)
Meter works


hmmmm, mysterious thing. My camera is 0x230a ,, and meter is working from startup....
startup register values has a more mysterious thins.

One more thing:
You already direct set/get memory value by PTP.  But I just added audio_ic_read/write code in php-chdk.c
I'm not write a PC side yet.
#285
General Development / Re: 600D Audio Controls?
July 25, 2012, 06:00:32 PM
Quote from: 1% on July 25, 2012, 05:42:29 PM
External for recording and internal for remote shot?

??? Are you asking my sentence about "you need to use both"????

#286
General Development / Re: 600D Audio Controls?
July 25, 2012, 05:36:48 PM
Quote from: 1% on July 25, 2012, 05:23:58 PM
(ML_PW_IN_PW_MNG | 0x0a) < this is what does it.
I don't know too. It's no entry in alsa driver. But this reg  value is 0x0a when a camera just startup

Quote from: 1% on July 25, 2012, 05:23:58 PM
(ML_REC_PLYBAK_RUN | 0x11); < rec mode is probably necessary too
I see. But reason is same. I still not thing about this.

We need find best value in my reset_audio()



Quote from: 1% on July 25, 2012, 05:23:58 PM
You can also call powermicamp from firmware.
Try with external mic.
Why you need to change this?
I think I have no problem to change audio setting in cannon menu.

Also , I don't need both int/ext mic at same time. Do you wanna use both same time?

Let me know what is your objective.
#287
General Development / Re: 600D Audio Controls?
July 25, 2012, 05:28:37 PM
great work 1%!!
I can't do this without your effort.Thank you very much

Anyway, currently the volume is back to just canon default value.
So I can't check audio level before recording , it is not good for me.(Just only work for audio remote shot )

one more analyzing needed.  and I hope we can use audio monitor .


---
external mic is working fine. Just switching ext mic only!!
#288
General Development / Re: 600D Audio Controls?
July 25, 2012, 04:34:13 PM
Audio remote shot is work perfectly!    confirmed.

My wife is shouting in front of my 600D now :D
#289
It's just a time to buy Atomos Ninja ?


I need to pay the money for buying HDMI cable.
I think it's best for  me....
#290
Quote from: 3pointedit on July 25, 2012, 01:32:42 PM
:P Oh too bad, doesnt the camera do macro?

I have only standard lens.  But Alia5 is good information to me!!

@Alia5
Thanks !!!!  I just forget the analog cable!
First, I need to find 600D paper box.

Oh,,, But how can I record SD video?(lol


It's like mebius.
#291
General Development / Re: 600D Audio Controls?
July 25, 2012, 04:22:31 PM
I Just push my repo.
I believe this logic is not so bad.

Then we need to find one more thing.

1: The audio register value is default(??) when 600d just launched
2: start recording or change vol, -> canon config value will write to audio IC
3: The audio switches on IC will power off when Stop recording or vol change finishd

3 is solved by my code.
But we don't know Actual audio setting in canon firmware. How can we know it?
when I understand it, I will change my reset_audio_setting() values.
#292
General Development / Re: 600D Audio Controls?
July 25, 2012, 03:52:54 PM
@ alex

I think
Phase 1: always work audio meter
Phase 2: audio monitor


Now phase 1 is not perfect. If I found good solution. I will send a patch for this.
#293
General Development / Re: 600D Audio Controls?
July 25, 2012, 03:02:17 PM
Quote from: miyake on July 25, 2012, 04:00:45 AM
I think, AUDIOREG-normal.txt is generated just startup.
My guess is, "It's not perfect initialization to common regesters yet"
When we touch recording,vol-change makes a first initialization will work.

My guess is correct !!!
Now 600D audio meter is not stop when finish recording!! and finished to change a volume from cannon menu
I'm rewrite a register value to startup's one  , when finished recording. then audio meter is always working.

Need more testers!Because I am setting reg under follow:
    audio_ic_write(ML_DVOL_CTL | 0x2E);
    audio_ic_write(ML_REC_PLYBAK_RUN | 0x11);
    audio_ic_write(ML_PW_IN_PW_MNG | 0x0a);
    audio_ic_write(ML_PW_MIC_IN_VOL | 0x3f);
    audio_ic_write(ML_PW_MIC_BOST_VOL | 0x10);
    audio_ic_write(ML_PW_AMP_VOL_FUNC | 0x01);
    audio_ic_write(ML_FILTER_EN | 0x0f);
    audio_ic_write(ML_MIXER_VOL_CTL | 0x10);


I guess it's volume setting is also back to this code's specific value.
But I don't know which one is it. Please help me to identify it.

Also 3 audio Property found and confirmed. I checked 0x2050001-0x205001F

https://bitbucket.org/miyake_t/magic-lantern-miyake/changeset/6c92e1942e54
My top priority is accomplished.
#294
Oh NO....
My sony NEX3 is need 45cm(18inch).
my magic arm is only 6inch...  orz...

@nanomaid
I'm thinking it. But HDMI cable is a little bit expensive. It's only for showing status of this debugging.

#295
OHhhhhhh! great idea. I already have it. But i didn't think it.
Thankyou!
#296
General Development / Re: 600D Audio Controls?
July 25, 2012, 04:00:45 AM
I need to go out from here.
1% if you interested in this things. Please clone my repo. And try yourself.


I think, AUDIOREG-normal.txt is generated just startup.
My guess is, "It's not perfect initialization to common regesters yet"
When we touch recording,vol-change makes a first initialization will work.

How do you think about this?
#297
General Development / Re: 600D Audio Controls?
July 25, 2012, 03:47:34 AM
vol70% vs vol0%